Struct CastIntoError
pub struct CastIntoError<'py> { /* private fields */ }Available on crate feature
tls only.Expand description
Equivalent to CastError for operations where the smart pointer cast transfers ownership
of the original object.
The original object can be retrieved using into_inner.
Implementations
impl<'py> CastIntoError<'py>
impl<'py> CastIntoError<'py>
pub fn new(
from: Bound<'py, PyAny>,
classinfo: Bound<'py, PyAny>,
) -> CastIntoError<'py>
pub fn new( from: Bound<'py, PyAny>, classinfo: Bound<'py, PyAny>, ) -> CastIntoError<'py>
Create a new CastError representing a failure to interpret a smart pointer to
from as a type from the given classinfo.
Equivalent to CastError::new for owned objects.
pub fn into_inner(self) -> Bound<'py, PyAny>
pub fn into_inner(self) -> Bound<'py, PyAny>
Consumes this CastIntoError and returns the original object, allowing continued
use of it after a failed conversion.
See cast_into for an example.